<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2012 - 2013 Michael Staatz <mstaatz@me.com>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

require_once(t3lib_extMgm::extPath('markdown_content') . 'lib/markdown.php');

/**
 * class tx_reload_markdown_files
 *
 */
class tx_reload_markdown_files {
	/**
	 * reload and refresh the markdown content that is included from files.
	 *
	 * @param array $cacheCmd
	 * @param object $pObj When using TYPO3 CMS >= 6.0.0 => TYPO3\CMS\Core\DataHandling\DataHandler
	 *                     When using TYPO3 CMS < 6.0.0 => t3lib_TCEmain
	 * @return void
	 * @see t3lib/class.t3lib_tcemain.php
	 */
	public function reload_markdown_files($cacheCmd, $pObj) {
			// clear cache for a single page
		if (t3lib_utility_Math::canBeInterpretedAsInteger($cacheCmd['cacheCmd'])) {
			$contentToRefresh = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows(
				'uid,bodytext,tx_markdown_content',
				'tt_content',
				'pid=' . (int) $cacheCmd['cacheCmd']
			);
		} else {
			$contentToRefresh = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows(
				'uid,bodytext,tx_markdown_content',
				'tt_content',
				'CType=\'markdown_content_pi1\''
			);
		}

		foreach ($contentToRefresh as $incomingFieldArray) {
			$bodyText = $this->generateMarkdownFromIncludeFile($incomingFieldArray['tx_markdown_content']);
			if (empty($bodyText)) {
				$bodyText = Markdown($incomingFieldArray['tx_markdown_content']);
			}
			$fieldsArray = array('bodytext' => $bodyText);
			$GLOBALS['TYPO3_DB']->exec_UPDATEquery(
				'tt_content',
				'uid=' . (int) $incomingFieldArray['uid'],
				$fieldsArray
			);
		}
	}

	/**
	 * Generate markdown from include file and update tt_content
	 *
	 * @param string $stringToParse
	 * @return string
	 */
	public function generateMarkdownFromIncludeFile($stringToParse) {
		$bodyText = '';
		$splitStr = '<INCLUDE_MARKDOWN:';
		if (strstr($stringToParse, $splitStr)) {
				// Adds line break char before/after
			$allParts = explode($splitStr, LF . $stringToParse . LF);
			foreach ($allParts as $c => $v) {
				$subparts = explode('>', $v, 2);
				if (preg_match('/^\\s*\\r?\\n/', $subparts[1])) {
					$params = t3lib_div::get_tag_attributes($subparts[0]);
					if ($params['source']) {
						$sourceParts = explode(':', $params['source'], 2);
						switch (strtolower(trim($sourceParts[0]))) {
						case 'file':
							$filename = t3lib_div::getFileAbsFileName(trim($sourceParts[1]));
								// Must exist and must not contain '..' and must be relative
							if (strcmp($filename, '')) {
									// Check for allowed files
								if (t3lib_div::verifyFilenameAgainstDenyPattern($filename)) {
									if (@is_file($filename)) {
											// Check for includes in included text
										$bodyText = Markdown(@file_get_contents($filename));
									}
								}
							}
						}
					}
				}
			}
		}
		return $bodyText;
	}
}

?>